@@ -192,7 +192,8 @@ class MaskedArray(awkward.array.base.AwkwardArrayWithContent):
         self._valid()
 
         if awkward.util.isstringslice(where):
-            return self.copy(content=self._content[where])
+            content = self._content[where]
+            return awkward.array.objects.Methods.maybemixin(type(content), MaskedArray)(self._mask, content, self._maskedwhen)
 
         if isinstance(where, tuple) and len(where) == 0:
             return self
@@ -482,7 +483,8 @@ class BitMaskedArray(MaskedArray):
         self._valid()
 
         if awkward.util.isstringslice(where):
-            return self.copy(content=self._content[where])
+            content = self._content[where]
+            return awkward.array.objects.Methods.maybemixin(type(content), BitMaskedArray)(self._mask, content, self._maskedwhen, self._lsborder)
 
         if isinstance(where, tuple) and len(where) == 0:
             return self
@@ -614,7 +616,8 @@ class IndexedMaskedArray(MaskedArray):
         self._valid()
 
         if awkward.util.isstringslice(where):
-            return self.copy(content=self._content[where])
+            content = self._content[where]
+            return awkward.array.objects.Methods.maybemixin(type(content), IndexedMaskedArray)(self._mask, content, self._maskedwhen)
 
         if isinstance(where, tuple) and len(where) == 0:
             return self
