@@ -272,6 +272,7 @@ class UnionArray(awkward.array.base.AwkwardArray):
             contents = []
             for tag in awkward.util.numpy.unique(self._tags):
                 contents.append(self._contents[tag][where])
+            # TODO: think about inheriting methods from contents[where]; all satisfying tags would have to have the same methods before promoting the output (generalized maybemixin?)
             if len(contents) == 0:
                 return self.copy(contents=[self._contents[0][where]])
             else:
@@ -437,5 +438,8 @@ class UnionArray(awkward.array.base.AwkwardArray):
                 out = [x for x in content.allcolumns if x in out]
         return out
 
+    def astype(self, dtype):
+        return self.copy(contents=[x.astype(dtype) for x in self._contents])
+
     def pandas(self):
         raise NotImplementedError
